# Py-Net

So Py-Net (Pine Nut, heh) is because I'm tired of rewriting network interfaces constantly.

Fix it here, fix it everywhere.

Contains a better thread, process, and connection. Allowing for easier control and termination of systems.

## Server

There's a `ServerNetworking` class in place to act as a server.

## Client

There's a `ClientNetworking` class in place to act as a client.


## Everything else

Is a WIP, meaning tests and documentation and bug fixes.